@@ -534,11 +534,12 @@ nsUnknownContentTypeDialog.prototype = {
       else
         typeString = mimeInfo.MIMEType;
     }
-    if (this.mLauncher.contentLength) {
+    // When the length is unknown, contentLength would be -1
+    if (this.mLauncher.contentLength >= 0) {
       let [size, unit] = DownloadUtils.
                          convertByteUnits(this.mLauncher.contentLength);
       type.value = this.dialogElement("strings")
-                       .getFormattedString("fileSizeWithType", 
+                       .getFormattedString("orderedFileSizeWithType", 
                                            [typeString, size, unit]);
     }
     else {
@@ -564,12 +565,12 @@ nsUnknownContentTypeDialog.prototype = {
   // Returns true if opening the default application makes sense.
   openWithDefaultOK: function() {
     // The checking is different on Windows...
-//@line 655 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 656 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     // On other platforms, default is Ok if there is a default app.
     // Note that nsIMIMEInfo providers need to ensure that this holds true
     // on each platform.
     return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 660 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 661 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // Set "default" application description field.
@@ -590,9 +591,9 @@ nsUnknownContentTypeDialog.prototype = {
 
   // getPath:
   getPath: function (aFile) {
-//@line 681 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 682 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return aFile.leafName || aFile.path;
-//@line 685 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 686 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // initAppAndSaveToDiskValues:
@@ -822,7 +823,7 @@ nsUnknownContentTypeDialog.prototype = {
         // for the file to be saved to to pass to |saveToDisk| - otherwise
         // we must ask the user to pick a save name.
 
-//@line 928 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 929 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
         // see @notify
         // we cannot use opener's setTimeout, see bug 420405
@@ -877,19 +878,19 @@ nsUnknownContentTypeDialog.prototype = {
   // Retrieve the pretty description from the file
   getFileDisplayName: function getFileDisplayName(file)
   {
-//@line 990 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 991 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     if (file instanceof Components.interfaces.nsILocalFileMac) {
       try {
         return file.bundleDisplayName;
       } catch (e) {}
     }
-//@line 996 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 997 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return file.leafName;
   },
 
   // chooseApp:  Open file picker and prompt user for application.
   chooseApp: function() {
-//@line 1044 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1045 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     var nsIFilePicker = Components.interfaces.nsIFilePicker;
     var fp = Components.classes["@mozilla.org/filepicker;1"]
                        .createInstance(nsIFilePicker);
@@ -906,7 +907,7 @@ nsUnknownContentTypeDialog.prototype = {
                    createInstance(Components.interfaces.nsILocalHandlerApp);
       localHandlerApp.executable = fp.file;
       this.chosenApp = localHandlerApp;
-//@line 1061 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1062 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
       // Show the "handler" menulist since we have a (user-specified)
       // application now.
